@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.45 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.46 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,7 +43,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.14.12');
+define('SYL_VERSION', '0.15.0');
 
 /**
  * ١ǥ쥯ȥ
@@ -64,11 +64,11 @@ define('SYL_LOG_DEBUG', 2047); // = E_ALL
 /**
  * 󥳡
  */
-define('SYL_ENCODE_INTERNAL', 'EUC-JP');
-define('SYL_ENCODE_JS',       'UTF-8');
-define('SYL_ENCODE_XML',      'UTF-8');
-define('SYL_ENCODE_XMLRPC',   'UTF-8');
-define('SYL_ENCODE_MAIL',     'ISO-2022-JP');
+if (!defined('SYL_ENCODE_INTERNAL')) define('SYL_ENCODE_INTERNAL', 'EUC-JP');
+if (!defined('SYL_ENCODE_JS'))       define('SYL_ENCODE_JS',       'UTF-8');
+if (!defined('SYL_ENCODE_XML'))      define('SYL_ENCODE_XML',      'UTF-8');
+if (!defined('SYL_ENCODE_XMLRPC'))   define('SYL_ENCODE_XMLRPC',   'UTF-8');
+if (!defined('SYL_ENCODE_MAIL'))     define('SYL_ENCODE_MAIL',     'ISO-2022-JP');
 
 /**
  * ॾPHP 5.1ʾ
