@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -134,15 +134,26 @@ class SyL_Data extends SyL_UtilProperty
      * 
      * @access public
      * @param string ץѥƥ̾
+     * @param mixed ǥե
+     * @param string ͭɽ
      * @return string ץѥƥ
      */
-    function get($name)
+    function get($name, $default=null, $reg=null)
     {
         $value = parent::get($name);
         if (($value === null) && isset($this->input_parameters[$name])) {
             $value = $this->input_parameters[$name];
         }
-        return $value;
+        if ($value === null) {
+            return $default;
+        } else {
+            if ($reg !== null) {
+                $reg = "/{$reg}/";
+                return preg_match($reg, $value) ? $value : $default;
+            } else {
+                return $value;
+            }
+        }
     }
 
     /**
@@ -150,15 +161,26 @@ class SyL_Data extends SyL_UtilProperty
      * 
      * @access public
      * @param string ץѥƥ̾
+     * @param mixed ǥե
+     * @param string ͭɽ
      * @return string ץѥƥ
      */
-    function &getRef($name)
+    function &getRef($name, $default=null, $valid=null)
     {
         $value =& parent::getRef($name);
         if (($value === null) && isset($this->input_parameters[$name])) {
             $value =& $this->input_parameters[$name];
         }
-        return $value;
+        if ($value === null) {
+            return $default;
+        } else {
+            if ($reg !== null) {
+                $reg = "/{$reg}/";
+                return preg_match($reg, $value) ? $value : $default;
+            } else {
+                return $value;
+            }
+        }
     }
 
     /**
@@ -247,7 +269,7 @@ class SyL_Data extends SyL_UtilProperty
      */
     function setInputs($input_parameters)
     {
-        $this->input_parameters = array_merge($this->input_parameters, $input_parameters);
+        $this->input_parameters = $input_parameters;
     }
 
     /**
@@ -272,7 +294,11 @@ class SyL_Data extends SyL_UtilProperty
      */
     function throwInputs()
     {
-        $this->sets($this->input_parameters);
+        foreach ($this->input_parameters as $name => $value) {
+            if (!parent::is($name)) {
+                $this->set($name, $value);
+            }
+        }
     }
 
     /**
