@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,42 +25,25 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter1_0.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter2_0.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * RSS 1.0饹
+ * RSS 2.0饹
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter1_0.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter2_0.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
+class SyL_XmlRssWriter2_0 extends SyL_XmlRssWriter
 {
-    /**
-     * Ǥ򥻥åȤ
-     * 
-     * @access public
-     * @param array 
-     */
-    function setImage($value)
-    {
-        parent::setImage($value);
-        if (isset($this->image['height'])) {
-            unset($this->image['height']);
-        }
-        if (isset($this->image['width'])) {
-            unset($this->image['width']);
-        }
-    }
-
     /**
      * ͥǤ򥻥åȤ
      * 
@@ -73,17 +56,16 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
     {
         // ݲ̾Ѵ
         switch ($name) {
-        case 'copyright':   $name = 'dc:right';    break;
-        case 'language':    $name = 'dc:language'; break;
-        case 'category':    $name = 'dc:subject';  break;
-        case 'contributor': $name = 'dc:contributor'; break;
-        case 'author':      $name = 'dc:creator'; break;
-        case 'id':          $name = 'dc:identifier'; break;
         case 'date':
-            $name = 'dc:date';
-        case 'dc:date':
+            $name = 'pubDate';
+        case 'pubDate':
+        case 'lastBuildDate':
             $value = $this->convertDateTime($value);
             break;
+        case 'contributor':
+        case 'author':
+        case 'id':
+            return;
         }
         parent::setChannel($name, $value, $attributes);
     }
@@ -101,35 +83,19 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
         // ݲ̾Ѵ
         foreach (array_keys($values) as $name) {
             switch ($name) {
-            case 'author':
-                $values['dc:creator'] = $values[$name];
+            case 'date':
+                $values['pubDate'] = $this->convertDateTime($values[$name]);
                 unset($values[$name]);
                 break;
-            case 'category':
-                $values['dc:subject'] = $values[$name];
-                unset($values[$name]);
+            case 'pubDate':
+                $values[$name] = $this->convertDateTime($values[$name]);
                 break;
-            case 'contributor':
-                $values['dc:contributor'] = $values[$name];
+            case 'id':
+                $values['guid'] = $values[$name];
                 unset($values[$name]);
                 break;
             case 'copyright':
-                $values['dc:right'] = $values[$name];
-                unset($values[$name]);
-                break;
-            case 'date':
-                $values['dc:date'] = $this->convertDateTime($values[$name]);
-                unset($values[$name]);
-                break;
-            case 'dc:date':
-                $values['dc:date'] = $this->convertDateTime($values[$name]);
-                break;
-            case 'id':
-                $values['dc:identifier'] = $values[$name];
-                unset($values[$name]);
-                break;
-            case 'source':
-                $values['dc:source'] = $values[$name];
+            case 'contributor':
                 unset($values[$name]);
                 break;
             }
@@ -144,49 +110,21 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
      */
     function createXml()
     {
-        $rdf_about = '';
-        foreach ($this->channel as $values) {
-            if ($values[0] == 'link') {
-                $rdf_about = $values[1];
-                break;
-            }
+        $version = '';
+        if (preg_match('/^SyL_XmlRssWriter(.+)$/i', get_class($this), $matches)) {
+            $version = str_replace('_', '.', $matches[1]);
         }
+        $this->addStartElement('rss', array('version' => $version));
+        $this->addStartElement('channel');
 
-        $this->addStartElement('rdf:RDF',
-          array(
-            'xmlns'     => 'http://purl.org/rss/1.0/',
-            'xmlns:rdf' => 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
-            'xmlns:dc'  => 'http://purl.org/dc/elements/1.1/'
-          )
-        );
-        $this->addStartElement('channel', array('rdf:about' => $rdf_about));
         // ͥ
-        foreach ($this->channel as $values) {
-            $this->createRecursiveElements($values[0], $values[1]);
+        foreach ($this->channel as $i => $values) {
+            $this->createRecursiveElements($values[0], $values[1], (isset($this->channel_attr[$i]) ? $this->channel_attr[$i] : array()));
         }
-        // 
-        if (count($this->image) > 0) {
-            $this->addElement('image', array('rdf:resource' => $this->image['url']));
-        }
-        // ƥ
-        if (count($this->textinput) > 0) {
-            $this->addElement('textinput', array('rdf:resource' => $this->textinput['link']));
-        }
-        // ƥ
-        if (count($this->items) > 0) {
-            $this->addStartElement('items');
-            $this->addStartElement('rdf:Seq');
-            foreach ($this->items as $item) {
-                $this->addElement('rdf:li', array('resource' => $item['link']));
-            }
-            $this->addEndElement();
-            $this->addEndElement();
-        }
-        $this->addEndElement();
 
         // 
         if (count($this->image) > 0) {
-            $this->addStartElement('image', array('rdf:about' => $this->image['url']));
+            $this->addStartElement('image');
             foreach ($this->image as $name => $value) {
                 $this->createRecursiveElements($name, $value);
             }
@@ -195,7 +133,7 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
 
         // ƥ
         if (count($this->textinput) > 0) {
-            $this->addStartElement('textinput', array('rdf:about' => $this->image['link']));
+            $this->addStartElement('textinput');
             foreach ($this->textinput as $name => $value) {
                 $this->createRecursiveElements($name, $value);
             }
@@ -204,7 +142,7 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
 
         // ƥ
         foreach ($this->items as $item) {
-            $this->addStartElement('item', array('rdf:about' => $item['link']));
+            $this->addStartElement('item');
             foreach ($item as $name => $value) {
                 $this->createRecursiveElements($name, $value);
             }
@@ -218,7 +156,7 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
     /**
      * եޥåȤѴ
      *
-     *  2007/03/14 19:44:00 -> 2007-03-14T19:44:00+09:00
+     * 2007/03/12 00:00:00 -> Mon, 12 Mar 2007 00:00:00 +0900
      *
      * @access public
      * @param string Ѵ
@@ -229,12 +167,11 @@ class SyL_XmlRssWriter1_0 extends SyL_XmlRssWriter
         if (preg_match('/^([0-9]{4})[\-|\/]?([0-1][0-9])[\-|\/]?([0-3][0-9])[ ]*([0-2][0-9]:?[0-5][0-9]:?[0-5][0-9])?$/', trim($datetime))) {
             $timestamp = @strtotime($datetime);
             if ($timestamp) {
-                $datetime = date('Y-m-d\TH:i:s+09:00', $timestamp);
+                $datetime = date('D, d M Y H:i:s +0900', $timestamp);
             }
         }
         return $datetime;
     }
-
 }
 
 ?>
