@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -325,6 +325,10 @@ class Index extends AppAction
         $table_foreigns = $schema->getForeigns($tablename);
         $conn->closeConnection();
 
+        if (count($table_columns) == 0) {
+            trigger_error("[SyL error] Table schema not found ({$tablename})", E_USER_ERROR);
+        }
+
         // -------------------------------------------------
         // ѿ˥å
         // -------------------------------------------------
@@ -637,7 +641,7 @@ class Index extends AppAction
         if ($action_name) {
             $action_name = '/' . strtolower($action_name);
             $cmd->stdout("--- URL ---"); ob_flush();
-            $cmd->stdout("  http://(hostname)/(controller_file){$action_name}/lst.html"); ob_flush();
+            $cmd->stdout("  http://(hostname)/(controller_file){$action_name}/"); ob_flush();
         }
     }
 
